==> jwt-servlet-auth-servlet3-1.0.1-sources.jar: io/telicent/servlet/auth/jwt/servlet3/Servlet3EngineProvider.java <==
/**
 * Copyright (C) Telicent Ltd
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.telicent.servlet.auth.jwt.servlet3;

import io.telicent.servlet.auth.jwt.JwtAuthenticationEngine;
import io.telicent.servlet.auth.jwt.configuration.AbstractHeaderBasedEngineProvider;
import io.telicent.servlet.auth.jwt.sources.HeaderSource;

import java.util.List;

/**
 * A provider for automated configuration of {@link Servlet3JwtAuthenticationEngine}
 */
public class Servlet3EngineProvider extends AbstractHeaderBasedEngineProvider {
    @Override
    @SuppressWarnings("unchecked")
    protected <TRequest, TResponse> JwtAuthenticationEngine<TRequest, TResponse> createEngine(
            List<HeaderSource> headerSources, String realm, List<String> usernameClaims) {
        return (JwtAuthenticationEngine<TRequest, TResponse>) new Servlet3JwtAuthenticationEngine(headerSources, realm,
                                                                                                  usernameClaims);
    }
}

==> jwt-servlet-auth-servlet3-2.0.0-sources.jar: io/telicent/servlet/auth/jwt/servlet3/Servlet3EngineProvider.java <==
/**
 * Copyright (C) Telicent Ltd
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.telicent.servlet.auth.jwt.servlet3;

import io.telicent.servlet.auth.jwt.JwtAuthenticationEngine;
import io.telicent.servlet.auth.jwt.configuration.AbstractHeaderBasedEngineProvider;
import io.telicent.servlet.auth.jwt.configuration.ClaimPath;
import io.telicent.servlet.auth.jwt.sources.HeaderSource;

import java.util.List;

/**
 * A provider for automated configuration of {@link Servlet3JwtAuthenticationEngine}
 */
public class Servlet3EngineProvider extends AbstractHeaderBasedEngineProvider {
    @Override
    @SuppressWarnings("unchecked")
    protected <TRequest, TResponse> JwtAuthenticationEngine<TRequest, TResponse> createEngine(
            List<HeaderSource> headerSources, String realm, List<ClaimPath> usernameClaims, ClaimPath rolesClaim) {
        return (JwtAuthenticationEngine<TRequest, TResponse>) new Servlet3JwtAuthenticationEngine(headerSources, realm,
                                                                                                  usernameClaims,
                                                                                                  rolesClaim);
    }
}
